summaryrefslogtreecommitdiffstats
path: root/quanta/treeviews/scripttreeview.h
diff options
context:
space:
mode:
Diffstat (limited to 'quanta/treeviews/scripttreeview.h')
-rw-r--r--quanta/treeviews/scripttreeview.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/quanta/treeviews/scripttreeview.h b/quanta/treeviews/scripttreeview.h
index 7cf2b145..1bfa934d 100644
--- a/quanta/treeviews/scripttreeview.h
+++ b/quanta/treeviews/scripttreeview.h
@@ -44,7 +44,7 @@ class ScriptTreeView : public BaseTreeView {
public:
- ScriptTreeView(QWidget *parent, const char *name = 0L);
+ ScriptTreeView(TQWidget *parent, const char *name = 0L);
~ScriptTreeView();
protected slots:
@@ -55,12 +55,12 @@ protected slots:
*
* @param listView KListView where the event comes from
*
* @param item QListViewItem where the mousepointer is hovering
*
* @param point QPoint coordinates of the event
*
*/
- virtual void slotMenu(KListView *listView, QListViewItem *item, const QPoint &point);
+ virtual void slotMenu(KListView *listView, TQListViewItem *item, const TQPoint &point);
/**
* slot of QListView
@@ -69,7 +69,7 @@ protected slots:
*
* @param item the selected QListViewItem
*/
- virtual void slotSelectFile(QListViewItem *item);
+ virtual void slotSelectFile(TQListViewItem *item);
/**
* slot for the RBM
@@ -157,7 +157,7 @@ signals:
/**
* emited from @ref slotAssignAction to open the assignment dialog
*/
- void assignActionToScript(const KURL&, const QString&);
+ void assignActionToScript(const KURL&, const TQString&);
/**
* emited to make the script describtion visible
@@ -172,7 +172,7 @@ signals:
/**
* request to upload the @ref fileName script tarball
*/
- void uploadScript(const QString& fileName);
+ void uploadScript(const TQString& fileName);
private:
/**
@@ -201,12 +201,12 @@ private:
*
* @return the value of the option
*/
- QString infoOptionValue(const KURL& infoURL, const QString& optionName);
+ TQString infoOptionValue(const KURL& infoURL, const TQString& optionName);
/** Create a script tarball which can be uploaded or sent in email. Returns
* the name of the created file or QString::null if creation has failed.
*/
- QString createScriptTarball();
+ TQString createScriptTarball();
/**
* remember the menu for manipulation
@@ -55,12 +55,12 @@ protected slots:
* @param listView KListView where the event comes from
*
- * @param item QListViewItem where the mousepointer is hovering
+ * @param item TQListViewItem where the mousepointer is hovering
*
@@ -55,12 +55,12 @@ protected slots:
*
- * @param point QPoint coordinates of the event
+ * @param point TQPoint coordinates of the event
*
*/
@@ -201,12 +201,12 @@ private:
/** Create a script tarball which can be uploaded or sent in email. Returns
- * the name of the created file or QString::null if creation has failed.
+ * the name of the created file or TQString::null if creation has failed.
*/